---
title: loadIssueBillingKeyUI 응답 형식
description: loadIssueBillingKeyUI 호출 결과로 받는 데이터의 형식을 확인할 수 있습니다.
targetVersions:
  - v2
versionVariants:
  v1: /sdk/ko/v1-sdk/javascript-sdk/payrt
---

## `loadIssueBillingKeyUI` 응답 데이터 정의

### onIssueBillingKeySuccess

- response: IssueBillingKeyResponse

  [definition link](https://developers.portone.io/schema/browser-sdk.yml#/resources/response/IssueBillingKeyResponse)

### onIssueBillingKeyFail

- response: IssueBillingKeyError

  [definition link](https://developers.portone.io/schema/browser-sdk.yml#/resources/exception/IssueBillingKeyError)
